import tkinter as tk
from tkinter import simpledialog, scrolledtext, messagebox, filedialog
import json
import os
import subprocess
import webbrowser
from datetime import datetime
import google.generativeai as genai

CONFIG_FILE = "config.json"
SCRIPTS_DIR = "scripts"
os.makedirs(SCRIPTS_DIR, exist_ok=True)

# פונקציה לשמירת API Key וסטטיסטיקות
def save_config(data):
    with open(CONFIG_FILE, 'w') as f:
        json.dump(data, f)

# פונקציה לטעינת קונפיג
def load_config():
    if os.path.exists(CONFIG_FILE):
        with open(CONFIG_FILE) as f:
            return json.load(f)
    return {"api_key": None, "usage": 0}

# אתחול Gemini
def init_gemini():
    cfg = load_config()
    if not cfg.get("api_key"):
        raise Exception("API Key לא מוגדר.")
    genai.configure(api_key=cfg["api_key"])
    return genai.GenerativeModel("models/gemini-1.5-pro-latest")

# חילוץ קוד מתוך תגובת Gemini
def extract_code(text):
    if "```python" in text:
        return text.split("```python")[1].split("```", 1)[0].strip()
    return text.strip()

# מחלקת GUI
class GeminiApp:
    def __init__(self, root):
        self.root = root
        self.root.title("Gemini - עוזר אישי")
        self.create_widgets()

    def create_widgets(self):
        top_frame = tk.Frame(self.root)
        top_frame.pack(fill='x', padx=10, pady=5)

        tk.Button(top_frame, text="🔐 הכנס API Key", command=self.set_api_key).grid(row=0, column=0, padx=5)
        tk.Button(top_frame, text="🌐 קבל API Key", command=lambda: webbrowser.open("https://aistudio.google.com/apikey")).grid(row=0, column=1, padx=5)
        tk.Button(top_frame, text="🧠 צור סקריפט עם Gemini", command=self.create_script).grid(row=0, column=2, padx=5)
        tk.Button(top_frame, text="▶️ הרץ סקריפט קיים", command=self.run_script).grid(row=0, column=3, padx=5)
        tk.Button(top_frame, text="📂 הצג סקריפטים", command=self.list_scripts).grid(row=0, column=4, padx=5)

        prompt_frame = tk.Frame(self.root)
        prompt_frame.pack(fill='x', padx=10, pady=5)

        tk.Label(prompt_frame, text="שאל את Gemini (Shift+Enter לרדת שורה, Enter לשליחה):").pack(anchor='w')
        self.prompt_entry = tk.Text(prompt_frame, height=4, wrap='word')
        self.prompt_entry.pack(fill='x')
        self.prompt_entry.bind("<Return>", self.on_enter_pressed)

        self.output = scrolledtext.ScrolledText(self.root, height=20)
        self.output.pack(fill='both', expand=True, padx=10, pady=10)

    def on_enter_pressed(self, event):
        if event.state & 0x0001:  # Shift pressed
            return
        self.create_script()
        return "break"

    def set_api_key(self):
        key = simpledialog.askstring("API Key", "הזן את המפתח שלך ל-Gemini:")
        if key:
            cfg = load_config()
            cfg["api_key"] = key
            save_config(cfg)
            messagebox.showinfo("נשמר", "המפתח נשמר בהצלחה.")

    def update_usage(self):
        cfg = load_config()
        cfg["usage"] = cfg.get("usage", 0) + 1
        save_config(cfg)

    def create_script(self):
        prompt = self.prompt_entry.get("1.0", "end").strip()
        if not prompt:
            return

        try:
            model = init_gemini()
            full_prompt = f"Create a Python script that {prompt}. Only output the code, without any explanation."
            response = model.generate_content(full_prompt)
            code = extract_code(response.text)

            self.output.insert('end', f"[Gemini תגובה מלאה]:\n{response.text}\n\n")

            filename = filedialog.asksaveasfilename(initialdir=SCRIPTS_DIR, defaultextension=".py", filetypes=[("Python files", "*.py")])
            if filename:
                if os.path.exists(filename):
                    timestamp = datetime.now().strftime("%Y%m%d%H%M%S")
                    backup_path = filename + f".bak.{timestamp}"
                    os.rename(filename, backup_path)
                    self.output.insert('end', f"[גיבוי] נשמרה גרסה קודמת: {backup_path}\n")

                with open(filename, 'w', encoding='utf-8') as f:
                    f.write(code)
                self.output.insert('end', f"[נשמר] הקובץ: {filename}\n\n")
                self.update_usage()
        except Exception as e:
            messagebox.showerror("שגיאה", str(e))

    def run_script(self):
        path = filedialog.askopenfilename(initialdir=SCRIPTS_DIR, filetypes=[("Python files", "*.py")])
        if path:
            try:
                result = subprocess.run(["python", path], capture_output=True, text=True)
                self.output.insert('end', f"[הרצה] {path}\n--- STDOUT ---\n{result.stdout}\n--- STDERR ---\n{result.stderr}\n\n")
            except Exception as e:
                self.output.insert('end', f"[שגיאה בהרצה] {e}\n\n")

    def list_scripts(self):
        files = os.listdir(SCRIPTS_DIR)
        py_files = [f for f in files if f.endswith(".py")]
        self.output.insert('end', f"[📁 סקריפטים בתיקייה '{SCRIPTS_DIR}']:\n" + "\n".join(py_files) + "\n\n")

if __name__ == '__main__':
    root = tk.Tk()
    app = GeminiApp(root)
    root.mainloop()
